@@ -49,7 +49,8 @@ from .misc import BreakReceived, SignalReceived, TerminalSizeChanged
 
 from .pbe import KeyEncryptionError
 
-from .process import SSHClientProcess, SSHCompletedProcess, ProcessError
+from .process import SSHClientProcess, SSHServerProcess
+from .process import SSHCompletedProcess, ProcessError
 from .process import DEVNULL, PIPE, STDOUT
 
 from .public_key import SSHKey, SSHKeyPair, SSHCertificate
@@ -61,12 +62,14 @@ from .public_key import read_private_key_list, read_public_key_list
 from .public_key import read_certificate_list
 from .public_key import load_keypairs, load_public_keys
 
+from .scp import scp
+
 from .session import SSHClientSession, SSHServerSession
 from .session import SSHTCPSession, SSHUNIXSession
 
 from .server import SSHServer
 
-from .sftp import SFTPClient, SFTPServer, SFTPFile, SFTPError
+from .sftp import SFTPClient, SFTPClientFile, SFTPServer, SFTPError
 from .sftp import SFTPAttrs, SFTPVFSAttrs, SFTPName
 from .sftp import SEEK_SET, SEEK_CUR, SEEK_END
 
